## v0.2.1 (2026-04-01)

### Fix

- specify python interpreters for cross-compiled Linux wheels
- trigger publish workflow on tag push instead of release

## v0.2.0 (2026-04-01)

### Feat

- add README and commitizen config for release management
